import { RangeSeekBarBase, minValueProperty, maxValueProperty, minStartValueProperty, maxStartValueProperty, minRangeProperty, stepProperty, cornerRadiusProperty, cornerRadiusCssProperty, barHeightProperty, barHeightCssProperty, barColorProperty, barColorCssProperty, barHighlightColorProperty, barHighlightColorCssProperty, thumbColorProperty, thumbColorCssProperty, } from "./range-seek-bar.common";
import { Utils } from '@nativescript/core';
export class RangeSeekBar extends RangeSeekBarBase {
    createNativeView() {
        const rangeSlider = TTRangeSlider.new();
        rangeSlider.hideLabels = true;
        rangeSlider.enableStep = true;
        rangeSlider.step = 1;
        rangeSlider.handleDiameter = Utils.layout.toDeviceIndependentPixels(20 * 2);
        rangeSlider.lineHeight = Utils.layout.toDeviceIndependentPixels(5);
        rangeSlider.selectedMinimum = 0;
        rangeSlider.selectedMaximum = 0;
        rangeSlider.selectedHandleDiameterMultiplier = 1.0;
        return rangeSlider;
    }
    onLoaded() {
        super.onLoaded();
        this.nativeView.frame = CGRectMake(0, 0, this.nativeView.superview.frame.size.width, 30);
        this.nativeView.delegate = this.rangeSeekBarDelegate = TTRangeSliderDelegateImpl.initWithOwner(new WeakRef(this));
    }
    updateMinStartValue(minValue) {
        this.nativeView.selectedMinimum = minValue;
    }
    updateMaxStartValue(maxValue) {
        this.nativeView.selectedMaximum = maxValue;
    }
    [minValueProperty.setNative](value) {
        this.nativeView.minValue = value;
    }
    [maxValueProperty.setNative](value) {
        this.nativeView.maxValue = value;
    }
    [minStartValueProperty.setNative](value) {
        this.nativeView.selectedMinimum = value;
    }
    [maxStartValueProperty.setNative](value) {
        this.nativeView.selectedMaximum = value;
    }
    [minRangeProperty.setNative](value) {
        this.nativeView.minDistance = value;
    }
    [stepProperty.setNative](value) {
        this.nativeView.step = value;
    }
    [cornerRadiusProperty.setNative](value) {
        this.nativeView.handleDiameter = Utils.layout.toDeviceIndependentPixels(value * 2);
    }
    [cornerRadiusCssProperty.setNative](value) {
        this.nativeView.handleDiameter = Utils.layout.toDeviceIndependentPixels(value * 2);
    }
    [barHeightProperty.setNative](value) {
        this.nativeView.lineHeight = Utils.layout.toDeviceIndependentPixels(value);
    }
    [barHeightCssProperty.setNative](value) {
        this.nativeView.lineHeight = Utils.layout.toDeviceIndependentPixels(value);
    }
    [barColorProperty.setNative](value) {
        this.nativeView.tintColor = value.ios;
    }
    [barColorCssProperty.setNative](value) {
        this.nativeView.tintColor = value.ios;
    }
    [barHighlightColorProperty.setNative](value) {
        this.nativeView.tintColorBetweenHandles = value.ios;
    }
    [barHighlightColorCssProperty.setNative](value) {
        this.nativeView.tintColorBetweenHandles = value.ios;
    }
    [thumbColorProperty.setNative](value) {
        this.nativeView.handleColor = value.ios;
    }
    [thumbColorCssProperty.setNative](value) {
        this.nativeView.handleColor = value.ios;
    }
}
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TTRangeSliderDelegateImpl = void 0;
var TTRangeSliderDelegateImpl = /** @class */ (function (_super) {
    __extends(TTRangeSliderDelegateImpl, _super);
    function TTRangeSliderDelegateImpl() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TTRangeSliderDelegateImpl_1 = TTRangeSliderDelegateImpl;
    TTRangeSliderDelegateImpl.initWithOwner = function (owner) {
        var delegate = TTRangeSliderDelegateImpl_1.new();
        delegate.owner = owner;
        return delegate;
    };
    TTRangeSliderDelegateImpl.prototype.rangeSliderDidChangeSelectedMinimumValueAndMaximumValue = function (sender, selectedMinimum, selectedMaximum) {
        if (this.owner && this.owner.get()) {
            var args = {
                eventName: RangeSeekBarBase.rangeSeekBarChangedEvent,
                object: sender,
                value: {
                    minValue: sender.selectedMinimum,
                    maxValue: sender.selectedMaximum
                }
            };
            this.owner.get().notify(args);
        }
    };
    TTRangeSliderDelegateImpl.prototype.didEndTouchesInRangeSlider = function (sender) {
        if (this.owner && this.owner.get()) {
            var args = {
                eventName: RangeSeekBarBase.rangeSeekBarFinalValueEvent,
                object: sender,
                value: {
                    minValue: sender.selectedMinimum,
                    maxValue: sender.selectedMaximum
                }
            };
            this.owner.get().notify(args);
        }
    };
    var TTRangeSliderDelegateImpl_1;
    TTRangeSliderDelegateImpl = TTRangeSliderDelegateImpl_1 = __decorate([
        ObjCClass(TTRangeSliderDelegate)
    ], TTRangeSliderDelegateImpl);
    return TTRangeSliderDelegateImpl;
}(NSObject));
exports.TTRangeSliderDelegateImpl = TTRangeSliderDelegateImpl;
//# sourceMappingURL=range-seek-bar.ios.js.map